diff options
| author | Gery Debongnie <ged@openerp.com> | 2014-04-30 09:47:33 +0200 |
|---|---|---|
| committer | Gery Debongnie <ged@openerp.com> | 2014-04-30 09:47:33 +0200 |
| commit | 36e3aac85ef60e39371d848bebcac265981d87f2 (patch) | |
| tree | 3c50cd002ff91db8ed8673f52f9d88928e877846 /addons/web/static/src | |
| parent | 2d41c2c7d517033e0a8f4f7ee91d24dd5f06c454 (diff) | |
[IMP] large optimizations to the graph view rendering (pivot table)
The pivot table rendering was slow with large tables : it appended to the
table each line, so the browser had to rerender each time the page. This
was solved by rendering the table to a document fragment, then only add
the fragment to the main document. This speeds up considerably the process
(from 2600ms to 420ms in one test)
Also, uses basic loops instead of underscore maps in the build_rows method
bzr revid: ged@openerp.com-20140430074733-quhfkzz33rlpahps
Diffstat (limited to 'addons/web/static/src')
0 files changed, 0 insertions, 0 deletions
